@@ -16,6 +16,7 @@ class DictConverter:
         *,
         posterior=None,
         posterior_predictive=None,
+        predictions=None,
         sample_stats=None,
         log_likelihood=None,
         prior=None,
@@ -23,11 +24,13 @@ class DictConverter:
         sample_stats_prior=None,
         observed_data=None,
         constant_data=None,
+        predictions_constant_data=None,
         coords=None,
         dims=None
     ):
         self.posterior = posterior
         self.posterior_predictive = posterior_predictive
+        self.predictions = predictions
         self.sample_stats = sample_stats
         self.log_likelihood = log_likelihood
         self.prior = prior
@@ -35,6 +38,7 @@ class DictConverter:
         self.sample_stats_prior = sample_stats_prior
         self.observed_data = observed_data
         self.constant_data = constant_data
+        self.predictions_constant_data = predictions_constant_data
         self.coords = coords
         self.dims = dims
 
@@ -89,6 +93,15 @@ class DictConverter:
 
         return dict_to_dataset(data, library=None, coords=self.coords, dims=self.dims)
 
+    @requires("predictions")
+    def predictions_to_xarray(self):
+        """Convert predictions to xarray."""
+        data = self.predictions
+        if not isinstance(data, dict):
+            raise TypeError("DictConverter.predictions is not a dictionary")
+
+        return dict_to_dataset(data, library=None, coords=self.coords, dims=self.dims)
+
     @requires("prior")
     def prior_to_xarray(self):
         """Convert prior samples to xarray."""
@@ -116,45 +129,41 @@ class DictConverter:
 
         return dict_to_dataset(data, library=None, coords=self.coords, dims=self.dims)
 
-    @requires("observed_data")
-    def observed_data_to_xarray(self):
-        """Convert observed_data to xarray."""
-        data = self.observed_data
+    def data_to_xarray(self, dct, group):
+        """Convert data to xarray."""
+        data = dct
         if not isinstance(data, dict):
-            raise TypeError("DictConverter.observed_data is not a dictionary")
+            raise TypeError("DictConverter.{} is not a dictionary".format(group))
         if self.dims is None:
             dims = {}
         else:
             dims = self.dims
-        observed_data = dict()
+        new_data = dict()
         for key, vals in data.items():
             vals = utils.one_de(vals)
             val_dims = dims.get(key)
             val_dims, coords = generate_dims_coords(
                 vals.shape, key, dims=val_dims, coords=self.coords
             )
-            observed_data[key] = xr.DataArray(vals, dims=val_dims, coords=coords)
-        return xr.Dataset(data_vars=observed_data, attrs=make_attrs(library=None))
+            new_data[key] = xr.DataArray(vals, dims=val_dims, coords=coords)
+        return xr.Dataset(data_vars=new_data, attrs=make_attrs(library=None))
+
+    @requires("observed_data")
+    def observed_data_to_xarray(self):
+        """Convert observed_data to xarray."""
+        return self.data_to_xarray(self.observed_data, group="observed_data")
 
     @requires("constant_data")
     def constant_data_to_xarray(self):
         """Convert constant_data to xarray."""
-        data = self.constant_data
-        if not isinstance(data, dict):
-            raise TypeError("DictConverter.constant_data is not a dictionary")
-        if self.dims is None:
-            dims = {}
-        else:
-            dims = self.dims
-        constant_data = dict()
-        for key, vals in data.items():
-            vals = utils.one_de(vals)
-            val_dims = dims.get(key)
-            val_dims, coords = generate_dims_coords(
-                vals.shape, key, dims=val_dims, coords=self.coords
-            )
-            constant_data[key] = xr.DataArray(vals, dims=val_dims, coords=coords)
-        return xr.Dataset(data_vars=constant_data, attrs=make_attrs(library=None))
+        return self.data_to_xarray(self.constant_data, group="constant_data")
+
+    @requires("predictions_constant_data")
+    def predictions_constant_data_to_xarray(self):
+        """Convert predictions_constant_data to xarray."""
+        return self.data_to_xarray(
+            self.predictions_constant_data, group="predictions_constant_data"
+        )
 
     def to_inference_data(self):
         """Convert all available data to an InferenceData object.
@@ -168,11 +177,13 @@ class DictConverter:
                 "sample_stats": self.sample_stats_to_xarray(),
                 "log_likelihood": self.log_likelihood_to_xarray(),
                 "posterior_predictive": self.posterior_predictive_to_xarray(),
+                "predictions": self.predictions_to_xarray(),
                 "prior": self.prior_to_xarray(),
                 "sample_stats_prior": self.sample_stats_prior_to_xarray(),
                 "prior_predictive": self.prior_predictive_to_xarray(),
                 "observed_data": self.observed_data_to_xarray(),
                 "constant_data": self.constant_data_to_xarray(),
+                "predictions_constant_data": self.predictions_constant_data_to_xarray(),
             }
         )
 
@@ -182,6 +193,7 @@ def from_dict(
     posterior=None,
     *,
     posterior_predictive=None,
+    predictions=None,
     sample_stats=None,
     log_likelihood=None,
     prior=None,
@@ -189,15 +201,20 @@ def from_dict(
     sample_stats_prior=None,
     observed_data=None,
     constant_data=None,
+    predictions_constant_data=None,
     coords=None,
     dims=None
 ):
     """Convert Dictionary data into an InferenceData object.
 
+    For a usage example read the
+    :doc:`Cookbook section on from_dict </notebooks/InferenceDataCookbook>`
+
     Parameters
     ----------
     posterior : dict
     posterior_predictive : dict
+    predictions: dict
     sample_stats : dict
     log_likelihood : dict
         For stats functions, log likelihood data should be stored here.
@@ -205,6 +222,7 @@ def from_dict(
     prior_predictive : dict
     observed_data : dict
     constant_data : dict
+    predictions_constant_data: dict
     coords : dict[str, iterable]
         A dictionary containing the values that are used as index. The key
         is the name of the dimension, the values are the index values.
@@ -218,6 +236,7 @@ def from_dict(
     return DictConverter(
         posterior=posterior,
         posterior_predictive=posterior_predictive,
+        predictions=predictions,
         sample_stats=sample_stats,
         log_likelihood=log_likelihood,
         prior=prior,
@@ -225,6 +244,7 @@ def from_dict(
         sample_stats_prior=sample_stats_prior,
         observed_data=observed_data,
         constant_data=constant_data,
+        predictions_constant_data=predictions_constant_data,
         coords=coords,
         dims=dims,
     ).to_inference_data()
