@@ -36,7 +36,7 @@ from .elpdplot import plot_elpd
 from .energyplot import plot_energy
 from .essplot import plot_ess
 from .forestplot import plot_forest
-from .hpdplot import plot_hpd
+from .hdiplot import plot_hdi
 from .jointplot import plot_joint
 from .kdeplot import plot_kde
 from .khatplot import plot_khat
