@@ -13,7 +13,7 @@ from .plot_utils import (
     get_plotting_function,
 )
 from ..rcparams import rcParams
-from ..utils import _var_names
+from ..utils import _var_names, credible_interval_warning
 
 
 # pylint:disable-msg=too-many-function-args
@@ -23,11 +23,11 @@ def plot_density(
     data_labels=None,
     var_names=None,
     transform=None,
-    credible_interval=None,
+    hdi_prob=None,
     point_estimate="auto",
     colors="cycle",
     outline=True,
-    hpd_markers="",
+    hdi_markers="",
     shade=0.0,
     bw=4.5,
     figsize=None,
@@ -36,11 +36,12 @@ def plot_density(
     backend=None,
     backend_kwargs=None,
     show=None,
+    credible_interval=None,
 ):
     """Generate KDE plots for continuous variables and histograms for discrete ones.
 
-    Plots are truncated at their 100*(1-alpha)% credible intervals. Plots are grouped per variable
-    and colors assigned to models.
+    Plots are truncated at their 100*(1-alpha)% highest density intervals. Plots are grouped per
+    variable and colors assigned to models.
 
     Parameters
     ----------
@@ -61,8 +62,9 @@ def plot_density(
         all the variables being plotted.
     transform : callable
         Function to transform data (defaults to None i.e. the identity function)
-    credible_interval : float
-        Credible intervals. Should be in the interval (0, 1]. Defaults to 0.94.
+    hdi_prob : float
+        Probability for the highest density interval. Should be in the interval (0, 1].
+        Defaults to 0.94.
     point_estimate : Optional[str]
         Plot point estimate per variable. Values should be 'mean', 'median', 'mode' or None.
         Defaults to 'auto' i.e. it falls back to default set in rcParams.
@@ -73,9 +75,9 @@ def plot_density(
         models. Defaults to `cycle`.
     outline : bool
         Use a line to draw KDEs and histograms. Default to True
-    hpd_markers : str
-        A valid `matplotlib.markers` like 'v', used to indicate the limits of the hpd interval.
-        Defaults to empty string (no marker).
+    hdi_markers : str
+        A valid `matplotlib.markers` like 'v', used to indicate the limits of the highest density
+        interval. Defaults to empty string (no marker).
     shade : Optional[float]
         Alpha blending value for the shaded area under the curve, between 0 (no shade) and 1
         (opaque). Defaults to 0.
@@ -88,8 +90,9 @@ def plot_density(
     textsize: Optional[float]
         Text size scaling factor for labels, titles and lines. If None it will be autoscaled based
         on figsize.
-    ax: axes, optional
-        Matplotlib axes or Bokeh figures.
+    ax: numpy array-like of matplotlib axes or bokeh figures, optional
+        A 2D array of locations into which to plot the densities. If not supplied, Arviz will create
+        its own array of plot areas (and return it).
     backend: str, optional
         Select plotting backend {"matplotlib","bokeh"}. Default "matplotlib".
     backend_kwargs: bool, optional
@@ -97,7 +100,8 @@ def plot_density(
         check the plotting method of the backend.
     show : bool, optional
         Call backend show function.
-
+    credible_interval: float, optional
+        deprecated: Please see hdi_prob
     Returns
     -------
     axes : matplotlib axes or bokeh figures
@@ -129,12 +133,12 @@ def plot_density(
 
         >>> az.plot_density([centered, non_centered], var_names=["mu"], group="prior")
 
-    Specify credible interval
+    Specify highest density interval
 
     .. plot::
         :context: close-figs
 
-        >>> az.plot_density([centered, non_centered], var_names=["mu"], credible_interval=.5)
+        >>> az.plot_density([centered, non_centered], var_names=["mu"], hdi_prob=.5)
 
     Shade plots and/or remove outlines
 
@@ -150,13 +154,17 @@ def plot_density(
 
         >>> az.plot_density([centered, non_centered], var_names=["mu"], bw=.9)
     """
-    if transform is not None:
-        data = transform(data)
+    if credible_interval:
+        hdi_prob = credible_interval_warning(credible_interval, hdi_prob)
+
     if not isinstance(data, (list, tuple)):
         datasets = [convert_to_dataset(data, group=group)]
     else:
         datasets = [convert_to_dataset(datum, group=group) for datum in data]
 
+    if transform is not None:
+        datasets = [transform(dataset) for dataset in datasets]
+
     var_names = _var_names(var_names, datasets)
     n_data = len(datasets)
 
@@ -181,11 +189,11 @@ def plot_density(
     elif isinstance(colors, str):
         colors = [colors for _ in range(n_data)]
 
-    if credible_interval is None:
-        credible_interval = rcParams["stats.credible_interval"]
+    if hdi_prob is None:
+        hdi_prob = rcParams["stats.hdi_prob"]
     else:
-        if not 1 >= credible_interval > 0:
-            raise ValueError("The value of credible_interval should be in the interval (0, 1]")
+        if not 1 >= hdi_prob > 0:
+            raise ValueError("The value of hdi_prob should be in the interval (0, 1]")
 
     to_plot = [list(xarray_var_iter(data, var_names, combined=True)) for data in datasets]
     all_labels = []
@@ -236,9 +244,9 @@ def plot_density(
         xt_labelsize=xt_labelsize,
         linewidth=linewidth,
         markersize=markersize,
-        credible_interval=credible_interval,
+        hdi_prob=hdi_prob,
         point_estimate=point_estimate,
-        hpd_markers=hpd_markers,
+        hdi_markers=hdi_markers,
         outline=outline,
         shade=shade,
         n_data=n_data,
