@@ -26,6 +26,7 @@ def plot_ppc(
     textsize=None,
     data_pairs=None,
     var_names=None,
+    filter_vars=None,
     coords=None,
     flatten=None,
     flatten_pp=None,
@@ -46,21 +47,21 @@ def plot_ppc(
 
     Parameters
     ----------
-    data : az.InferenceData object
+    data: az.InferenceData object
         InferenceData object containing the observed and posterior/prior predictive data.
-    kind : str
+    kind: str
         Type of plot to display (kde, cumulative, or scatter). Defaults to kde.
-    alpha : float
+    alpha: float
         Opacity of posterior/prior predictive density curves.
         Defaults to 0.2 for kind = kde and cumulative, for scatter defaults to 0.7
-    mean : bool
+    mean: bool
         Whether or not to plot the mean posterior/prior predictive distribution. Defaults to True
-    figsize : tuple
+    figsize: tuple
         Figure size. If None it will be defined automatically.
     textsize: float
         Text size scaling factor for labels, titles and lines. If None it will be
         autoscaled based on figsize.
-    data_pairs : dict
+    data_pairs: dict
         Dictionary containing relations between observed data and posterior/prior predictive data.
         Dictionary structure:
 
@@ -70,56 +71,71 @@ def plot_ppc(
         For example, `data_pairs = {'y' : 'y_hat'}`
         If None, it will assume that the observed data and the posterior/prior
         predictive data have the same variable name.
-    var_names : list
-        List of variables to be plotted. Defaults to all observed variables in the
-        model if None.
-    coords : dict
+    var_names: list of variable names
+        Variables to be plotted, if `None` all variable are plotted. Prefix the
+        variables by `~` when you want to exclude them from the plot.
+    filter_vars: {None, "like", "regex"}, optional, default=None
+        If `None` (default), interpret var_names as the real variables names. If "like",
+        interpret var_names as substrings of the real variables names. If "regex",
+        interpret var_names as regular expressions on the real variables names. A la
+        `pandas.filter`.
+    coords: dict
         Dictionary mapping dimensions to selected coordinates to be plotted.
         Dimensions without a mapping specified will include all coordinates for
         that dimension. Defaults to including all coordinates for all
         dimensions if None.
-    flatten : list
+    flatten: list
         List of dimensions to flatten in observed_data. Only flattens across the coordinates
         specified in the coords argument. Defaults to flattening all of the dimensions.
-    flatten_pp : list
+    flatten_pp: list
         List of dimensions to flatten in posterior_predictive/prior_predictive. Only flattens
         across the coordinates specified in the coords argument. Defaults to flattening all
         of the dimensions. Dimensions should match flatten excluding dimensions for data_pairs
         parameters. If flatten is defined and flatten_pp is None, then `flatten_pp=flatten`.
-    num_pp_samples : int
+    num_pp_samples: int
         The number of posterior/prior predictive samples to plot. For `kind` = 'scatter' and
         `animation = False` if defaults to a maximum of 5 samples and will set jitter to 0.7
         unless defined otherwise. Otherwise it defaults to all provided samples.
-    random_seed : int
+    random_seed: int
         Random number generator seed passed to numpy.random.seed to allow
         reproducibility of the plot. By default, no seed will be provided
         and the plot will change each call if a random sample is specified
         by `num_pp_samples`.
-    jitter : float
+    jitter: float
         If kind is "scatter", jitter will add random uniform noise to the height
         of the ppc samples and observed data. By default 0.
-    animated : bool
+    animated: bool
         Create an animation of one posterior/prior predictive sample per frame. Defaults to False.
+        Only works with matploblib backend.
+        To run animations inside a notebook you have to use the `nbAgg` matplotlib's backend.
+        Try with `%matplotlib notebook` or  `%matplotlib  nbAgg`. You can switch back to the
+        default matplotlib's backend with `%matplotlib  inline` or `%matplotlib  auto`.
+        If switching back and forth between matplotlib's backend, you may need to run twice the cell
+        with the animation.
+        If you experience problems rendering the animation try setting
+        `animation_kwargs({'blit':False}) or changing the matplotlib's backend (e.g. to TkAgg)
+        If you run the animation from a script write `ax, ani = az.plot_ppc(.)`
     animation_kwargs : dict
-        Keywords passed to `animation.FuncAnimation`.
+        Keywords passed to `animation.FuncAnimation`. Ignored with matploblib backend.
     legend : bool
         Add legend to figure. By default True.
-    ax: axes, optional
-        Matplotlib axes or bokeh figures.
+    ax: numpy array-like of matplotlib axes or bokeh figures, optional
+        A 2D array of locations into which to plot the densities. If not supplied, Arviz will create
+        its own array of plot areas (and return it).
     backend: str, optional
         Select plotting backend {"matplotlib","bokeh"}. Default "matplotlib".
     backend_kwargs: bool, optional
         These are kwargs specific to the backend being used. For additional documentation
         check the plotting method of the backend.
-    group : {"prior", "posterior"}, optional
+    group: {"prior", "posterior"}, optional
         Specifies which InferenceData group should be plotted. Defaults to 'posterior'.
         Other value can be 'prior'.
-    show : bool, optional
+    show: bool, optional
         Call backend show function.
 
     Returns
     -------
-    axes : matplotlib axes or bokeh figures
+    axes: matplotlib axes or bokeh figures
 
     Examples
     --------
@@ -130,8 +146,8 @@ def plot_ppc(
 
         >>> import arviz as az
         >>> data = az.load_arviz_data('radon')
-        >>> az.plot_ppc(data,data_pairs={"obs":"obs"})
-        >>> #az.plot_ppc(data,data_pairs={"obs":"obs_hat"})
+        >>> az.plot_ppc(data, data_pairs={"obs":"obs"})
+        >>> #az.plot_ppc(data, data_pairs={"obs":"obs_hat"})
 
     Plot the overlay with empirical CDFs.
 
@@ -179,6 +195,10 @@ def plot_ppc(
     if data_pairs is None:
         data_pairs = {}
 
+    if backend is None:
+        backend = rcParams["plot.backend"]
+    backend = backend.lower()
+
     if animation_kwargs is None:
         animation_kwargs = {}
     if platform.system() == "Linux":
@@ -186,15 +206,6 @@ def plot_ppc(
     else:
         animation_kwargs.setdefault("blit", False)
 
-    if animated and backend == "bokeh":
-        raise TypeError("Animation option is only supported with matplotlib backend.")
-
-    if animated and animation_kwargs["blit"] and platform.system() != "Linux":
-        _log.warning(
-            "If you experience problems rendering the animation try setting"
-            "`animation_kwargs({'blit':False}) or changing the plotting backend (e.g. to TkAgg)"
-        )
-
     if alpha is None:
         if animated:
             alpha = 1
@@ -217,9 +228,9 @@ def plot_ppc(
 
     if var_names is None:
         var_names = list(observed.data_vars)
-    var_names = _var_names(var_names, observed)
+    var_names = _var_names(var_names, observed, filter_vars)
     pp_var_names = [data_pairs.get(var, var) for var in var_names]
-    pp_var_names = _var_names(pp_var_names, predictive_dataset)
+    pp_var_names = _var_names(pp_var_names, predictive_dataset, filter_vars)
 
     if flatten_pp is None and flatten is None:
         flatten_pp = list(predictive_dataset.dims.keys())
@@ -311,11 +322,9 @@ def plot_ppc(
         show=show,
     )
 
-    if backend is None:
-        backend = rcParams["plot.backend"]
-    backend = backend.lower()
-
     if backend == "bokeh":
+        if animated:
+            raise TypeError("Animation option is only supported with matplotlib backend.")
 
         ppcplot_kwargs.pop("animated")
         ppcplot_kwargs.pop("animation_kwargs")
