@@ -188,9 +188,9 @@ def test_plot_trace_discrete(discrete_model):
 
 def test_plot_trace_max_subplots_warning(models):
     with pytest.warns(UserWarning):
-        with rc_context(rc={"plot.max_subplots": 1}):
+        with rc_context(rc={"plot.max_subplots": 6}):
             axes = plot_trace(models.model_1)
-    assert axes.shape
+    assert axes.shape == (3, 2)
 
 
 @pytest.mark.parametrize("kwargs", [{"var_names": ["mu", "tau"], "lines": [("hey", {}, [1])]}])
@@ -478,6 +478,21 @@ def test_plot_pair_overlaid(models, kwargs):
     assert ax.shape
 
 
+@pytest.mark.parametrize("marginals", [True, False])
+@pytest.mark.parametrize("max_subplots", [True, False])
+def test_plot_pair_shapes(marginals, max_subplots):
+    rng = np.random.default_rng()
+    idata = from_dict({"a": rng.standard_normal((4, 500, 5))})
+    if max_subplots:
+        with rc_context({"plot.max_subplots": 6}):
+            with pytest.warns(UserWarning, match="3x3 grid"):
+                ax = plot_pair(idata, marginals=marginals)
+    else:
+        ax = plot_pair(idata, marginals=marginals)
+    side = 3 if max_subplots else (4 + marginals)
+    assert ax.shape == (side, side)
+
+
 @pytest.mark.parametrize("kind", ["kde", "cumulative", "scatter"])
 @pytest.mark.parametrize("alpha", [None, 0.2, 1])
 @pytest.mark.parametrize("animated", [False, True])
